@@ -59,7 +59,7 @@ if (isset($params['category']))
 	
 // MyEvents ? if 1, only display the current loggedin user events (to which he is registered to)
 $myevents = false;
-if (isset($params['myevents']) AND $params['myevents'])
+if (isset($params['myevents']) AND ($params['myevents']==1 OR $params['myevents'] == 'true'))
 	$myevents = true;
 	
 // Load the events
